@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from collections.abc import Iterable, Iterator, Sequence
-from typing import Any, Callable, ClassVar, Generic, Protocol
+from typing import Any, Callable, ClassVar, Generic, Protocol, Tuple, cast
 from urllib.parse import unquote, urldefrag, urljoin
 
 from attrs import evolve, field
@@ -12,7 +12,10 @@ from referencing import exceptions
 from referencing._attrs import frozen
 from referencing.typing import URI, Anchor as AnchorType, D, Mapping
 
-EMPTY64 = pmap(pre_size=64)
+EMPTY_RESOURCES: PMap[URI, Resource[Any]] = pmap({}, pre_size=64)
+EMPTY_ANCHORS = cast(PMap[Tuple[URI, str], AnchorType[Any]], EMPTY_RESOURCES)
+EMPTY_UNCRAWLED: PSet[URI] = pset(pre_size=128)
+EMPTY_PREVIOUS_RESOLVERS: PList[URI] = plist()
 
 
 class _MaybeInSubresource(Protocol[D]):
@@ -228,16 +231,19 @@ class Registry(Mapping[URI, Resource[D]]):
     The ``retrieve`` argument can be used to configure retrieval of resources
     dynamically, either over the network, from a database, or the like.
     Pass it a callable which will be called if any URI not present in the
-    registry is accessed. It must either return a `Resource` or else raise an
-    exception indicating that the resource is not retrievable.
+    registry is accessed. It must either return a `Resource` or else raise a
+    `NoSuchResource` exception indicating that the resource does not exist
+    even according to the retrieval logic.
     """
 
     _resources: PMap[URI, Resource[D]] = field(
-        default=EMPTY64,  # type: ignore[reportUnknownArgumentType]
+        default=EMPTY_RESOURCES,
         converter=_to_pmap,
     )
-    _anchors: PMap[tuple[URI, str], AnchorType[D]] = field(default=EMPTY64)  # type: ignore[reportUnknownArgumentType]  # noqa: E501
-    _uncrawled: PSet[URI] = field(default=pset())  # type: ignore[reportUnknownArgumentType]  # noqa: E501
+    _anchors: PMap[tuple[URI, str], AnchorType[D]] = field(
+        default=EMPTY_ANCHORS,
+    )
+    _uncrawled: PSet[URI] = field(default=EMPTY_UNCRAWLED)
     _retrieve: Callable[[URI], Resource[D]] = field(default=_fail_to_retrieve)
 
     def __getitem__(self, uri: URI) -> Resource[D]:
@@ -331,7 +337,7 @@ class Registry(Mapping[URI, Resource[D]]):
             self,
             resources=resources.persistent(),
             anchors=anchors.persistent(),
-            uncrawled=pset(),
+            uncrawled=EMPTY_UNCRAWLED,
         )
 
     def with_resource(self, uri: URI, resource: Resource[D]):
@@ -377,14 +383,14 @@ class Registry(Mapping[URI, Resource[D]]):
         """
         if registries == (self,):
             return self
-        anchors = self._anchors
         resources = self._resources
+        anchors = self._anchors
         uncrawled = self._uncrawled
         retrieve = self._retrieve
         for registry in registries:
-            anchors = anchors.update(registry._anchors)  # type: ignore[reportUnknownMemberType]  # noqa: E501
             resources = resources.update(registry._resources)  # type: ignore[reportUnknownMemberType]  # noqa: E501
-            uncrawled = uncrawled.update(registry._uncrawled)  # type: ignore[reportUnknownMemberType]  # noqa: E501
+            anchors = anchors.update(registry._anchors)  # type: ignore[reportUnknownMemberType]  # noqa: E501
+            uncrawled = uncrawled.update(registry._uncrawled)
 
             if registry._retrieve != _fail_to_retrieve:
                 if registry._retrieve != retrieve != _fail_to_retrieve:
@@ -448,7 +454,7 @@ class Resolver(Generic[D]):
     _base_uri: str = field(alias="base_uri")
     _registry: Registry[D] = field(alias="registry")
     _previous: PList[URI] = field(
-        default=plist(),  # type: ignore[reportUnknownArgumentType]
+        default=EMPTY_PREVIOUS_RESOLVERS,
         repr=False,
         alias="previous",
     )
